| Title: | Confounding Explorer |
|---|---|
| Description: | This package provides a simple interactive application for investigating the effect of confounding between a signal of interest and a batch effect. It uses simulated data with user-specified effect sizes for both batch and condition effects. The user can also specify the number of samples in each condition and batch, and thereby the degree of confounding. |
| Authors: | Charlotte Soneson [aut, cre] (ORCID: <https://orcid.org/0000-0003-3833-2169>) |
| Maintainer: | Charlotte Soneson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.1 |
| Built: | 2026-05-25 07:47:35 UTC |
| Source: | https://github.com/csoneson/ConfoundingExplorer |
Confounding explorer
ConfoundingExplorer( sampleSizes = matrix(rep(5, 4), nrow = 2, dimnames = list(c("group1", "group2"), c("batch1", "batch2"))), fracVarCond = 0.25, fracVarBatch = 0.5, fracVarUnknown = 0, condEffectSize = 3, batchEffectSize = 3, unknownEffectSize = 0, unknownEffectType = "categorical", analysisApproach = "dontAdjust", seed = 123, addStopButton = TRUE )ConfoundingExplorer( sampleSizes = matrix(rep(5, 4), nrow = 2, dimnames = list(c("group1", "group2"), c("batch1", "batch2"))), fracVarCond = 0.25, fracVarBatch = 0.5, fracVarUnknown = 0, condEffectSize = 3, batchEffectSize = 3, unknownEffectSize = 0, unknownEffectType = "categorical", analysisApproach = "dontAdjust", seed = 123, addStopButton = TRUE )
sampleSizes |
2x2 numeric matrix giving the number of samples in each group. Row names must be c('group1', 'group2') and column names must be c('batch1', 'batch2'). |
fracVarCond, fracVarBatch, fracVarUnknown
|
Numeric scalars between 0 and 1. The fraction of variables affected by the condition effect, batch effect, and 'unknown' effect, respectively. |
condEffectSize, batchEffectSize, unknownEffectSize
|
Numeric scalars. The condition, batch and 'unknown' effect size, respectively. |
unknownEffectType |
Character scalar, either 'categorical' or 'continuous', representing the type of 'unknown' effect to add. |
analysisApproach |
Character scalar. One of 'dontAdjust', 'inclBatch', 'removeBatch', 'removeBatchAccCond'. Determines what model is fit to the data. |
seed |
Numeric scalar, the random seed to use when simulating data. |
addStopButton |
Logical scalar. If |
A shinyApp object
Charlotte Soneson
if (interactive()) { ConfoundingExplorer() }if (interactive()) { ConfoundingExplorer() }